==> kbarcode_2.0.5.orig.tar.gz: kbarcode-2.0.5.orig/kbarcode/dstextedit.h <==
/***************************************************************************
                         dstextedit.h  -  description
                             -------------------
    begin                : Sam Jun 04 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _DS_TEXT_EDIT_H_
#define _DS_TEXT_EDIT_H_

#include <qnamespace.h> 

#if QT_VERSION >= 0x030100
    #include <ktextedit.h>
#else
    #include <qtextedit.h>
#endif

// Otherwise moc will complain
#if QT_VERSION >= 0x030100
  #define TextEditBase KTextEdit
#else
  #define TextEditBase QTextEdit
#endif 

class DSTextEdit : public TextEditBase {
    Q_OBJECT
        
  public:
    DSTextEdit( QWidget* parent, const char* name = 0 );

    //virtual void moveCursor( CursorAction action, bool select );
  private slots:
    void fixParagraphs();
      
  private:
    /** 
     * returns true if the cursor is currently inside
     * of a token of the form [value].
     */
    //bool cursorIsInToken();
};

#endif // _DS_TEXT_EDIT_H_

==> kbarcode_2.0.7.orig.tar.gz: kbarcode-2.0.7/kbarcode/dstextedit.h <==
/***************************************************************************
                         dstextedit.h  -  description
                             -------------------
    begin                : Sam Jun 04 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _DS_TEXT_EDIT_H_
#define _DS_TEXT_EDIT_H_

#include <qnamespace.h> 

#include <ktextedit.h>

class DSTextEdit : public KTextEdit {
    Q_OBJECT
        
  public:
    DSTextEdit( QWidget* parent, const char* name = 0 );

    //virtual void moveCursor( CursorAction action, bool select );
  private slots:
    void fixParagraphs();
      
  private:
    /** 
     * returns true if the cursor is currently inside
     * of a token of the form [value].
     */
    //bool cursorIsInToken();
};

#endif // _DS_TEXT_EDIT_H_
